@@ -18,7 +18,8 @@
 
 /* This file contains the XDMCP chooser glue */
 
-#include <config.h> 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <syslog.h>
